aboutsummaryrefslogtreecommitdiffstats
path: root/g10
diff options
context:
space:
mode:
Diffstat (limited to 'g10')
-rw-r--r--g10/encrypt.c2
-rw-r--r--g10/getkey.c4
-rw-r--r--g10/gpg.c4
-rw-r--r--g10/gpgv.c2
-rw-r--r--g10/import.c2
-rw-r--r--g10/keydb.c2
-rw-r--r--g10/keydb.h8
-rw-r--r--g10/keygen.c2
-rw-r--r--g10/keyid.c2
-rw-r--r--g10/keylist.c2
-rw-r--r--g10/keyring.c2
-rw-r--r--g10/mainproc.c6
-rw-r--r--g10/misc.c8
-rw-r--r--g10/options.h2
-rw-r--r--g10/packet.h4
-rw-r--r--g10/parse-packet.c2
-rw-r--r--g10/pkclist.c4
-rw-r--r--g10/pkglue.c2
-rw-r--r--g10/plaintext.c2
-rw-r--r--g10/server.c2
-rw-r--r--g10/sig-check.c2
-rw-r--r--g10/sqlite.c2
-rw-r--r--g10/tdbio.c6
-rw-r--r--g10/test-stubs.c2
-rw-r--r--g10/tofu.c2
-rw-r--r--g10/trust.c4
-rw-r--r--g10/trustdb.c2
27 files changed, 42 insertions, 42 deletions
diff --git a/g10/encrypt.c b/g10/encrypt.c
index 8bdbe8c2d..4432f293b 100644
--- a/g10/encrypt.c
+++ b/g10/encrypt.c
@@ -85,7 +85,7 @@ encrypt_seskey (DEK *dek, DEK **seskey, byte *enckey)
buf[0] = (*seskey)->algo;
memcpy( buf + 1, (*seskey)->key, (*seskey)->keylen );
- /* We only pass already checked values to the following fucntion,
+ /* We only pass already checked values to the following function,
thus we consider any failure as fatal. */
if (openpgp_cipher_open (&hd, dek->algo, GCRY_CIPHER_MODE_CFB, 1))
BUG ();
diff --git a/g10/getkey.c b/g10/getkey.c
index 7238bc39a..dd6820be2 100644
--- a/g10/getkey.c
+++ b/g10/getkey.c
@@ -986,7 +986,7 @@ get_pubkey_byname (ctrl_t ctrl, GETKEY_CTX * retctx, PKT_public_key * pk,
add_to_strlist (&namelist, fpr_string);
}
else if (!rc && !fpr && !did_key_byname)
- /* The acquisition method said no failure occured, but it
+ /* The acquisition method said no failure occurred, but it
didn't return a fingerprint. That's a failure. */
{
no_fingerprint = 1;
@@ -2297,7 +2297,7 @@ merge_selfsigs_subkey (KBNODE keyblock, KBNODE subnode)
if (backsig)
{
- /* At ths point, backsig contains the most recent 0x19 sig.
+ /* At this point, backsig contains the most recent 0x19 sig.
Let's see if it is good. */
/* 2==valid, 1==invalid, 0==didn't check */
diff --git a/g10/gpg.c b/g10/gpg.c
index 75060b821..dacfa7489 100644
--- a/g10/gpg.c
+++ b/g10/gpg.c
@@ -2008,7 +2008,7 @@ parse_tofu_db_format (const char *db_format)
}
}
-/* This fucntion called to initialized a new control object. It is
+/* This function called to initialized a new control object. It is
assumed that this object has been zeroed out before calling this
function. */
static void
@@ -3579,7 +3579,7 @@ main (int argc, char **argv)
/* Do these after the switch(), so they can override settings. */
if(PGP6)
{
- /* That does not anymore work becuase we have no more support
+ /* That does not anymore work because we have no more support
for v3 signatures. */
opt.disable_mdc=1;
opt.escape_from=1;
diff --git a/g10/gpgv.c b/g10/gpgv.c
index d39eb6622..993275671 100644
--- a/g10/gpgv.c
+++ b/g10/gpgv.c
@@ -242,7 +242,7 @@ g10_exit( int rc )
/* Stub:
- * We have to override the trustcheck from pkclist.c becuase
+ * We have to override the trustcheck from pkclist.c because
* this utility assumes that all keys in the keyring are trustworthy
*/
int
diff --git a/g10/import.c b/g10/import.c
index 0847a9a86..e1577b8a1 100644
--- a/g10/import.c
+++ b/g10/import.c
@@ -1638,7 +1638,7 @@ sec_to_pub_keyblock (kbnode_t sec_keyblock)
/****************
* Ditto for secret keys. Handling is simpler than for public keys.
* We allow secret key importing only when allow is true, this is so
- * that a secret key can not be imported accidently and thereby tampering
+ * that a secret key can not be imported accidentally and thereby tampering
* with the trust calculation.
*/
static int
diff --git a/g10/keydb.c b/g10/keydb.c
index bcafe907b..1705c7135 100644
--- a/g10/keydb.c
+++ b/g10/keydb.c
@@ -156,7 +156,7 @@ static int lock_all (KEYDB_HANDLE hd);
static void unlock_all (KEYDB_HANDLE hd);
-/* Check whether the keyid KID is in key id is definately not in the
+/* Check whether the keyid KID is in key id is definitely not in the
database.
Returns:
diff --git a/g10/keygen.c b/g10/keygen.c
index 70d351db6..4296fe7fd 100644
--- a/g10/keygen.c
+++ b/g10/keygen.c
@@ -1284,7 +1284,7 @@ do_create_from_keygrip (ctrl_t ctrl, int algo, const char *hexkeygrip,
}
-/* Common code for the key generation fucntion gen_xxx. */
+/* Common code for the key generation function gen_xxx. */
static int
common_gen (const char *keyparms, int algo, const char *algoelem,
kbnode_t pub_root, u32 timestamp, u32 expireval, int is_subkey,
diff --git a/g10/keyid.c b/g10/keyid.c
index de46d7212..d71698594 100644
--- a/g10/keyid.c
+++ b/g10/keyid.c
@@ -785,7 +785,7 @@ format_hexfingerprint (const char *fingerprint, char *buffer, size_t buflen)
/* Return the so called KEYGRIP which is the SHA-1 hash of the public
key parameters expressed as an canoncial encoded S-Exp. ARRAY must
- be 20 bytes long. Returns 0 on sucess or an error code. */
+ be 20 bytes long. Returns 0 on success or an error code. */
gpg_error_t
keygrip_from_pk (PKT_public_key *pk, unsigned char *array)
{
diff --git a/g10/keylist.c b/g10/keylist.c
index 2923a13e3..9b2d83f10 100644
--- a/g10/keylist.c
+++ b/g10/keylist.c
@@ -903,7 +903,7 @@ list_keyblock_pka (ctrl_t ctrl, kbnode_t keyblock)
size_t datalen;
gpg_error_t err;
- /* We do not have an export fucntion which allows to pass a
+ /* We do not have an export function which allows to pass a
keyblock, thus we need to search the key again. */
err = export_pubkey_buffer (ctrl, hexfpr,
EXPORT_DANE_FORMAT, NULL,
diff --git a/g10/keyring.c b/g10/keyring.c
index 4e2145f54..8ebc2e455 100644
--- a/g10/keyring.c
+++ b/g10/keyring.c
@@ -1215,7 +1215,7 @@ create_tmp_file (const char *template,
# ifdef USE_ONLY_8DOT3
/* Here is another Windoze bug?:
- * you cant rename("pubring.gpg.tmp", "pubring.gpg");
+ * you can't rename("pubring.gpg.tmp", "pubring.gpg");
* but rename("pubring.gpg.tmp", "pubring.aaa");
* works. So we replace .gpg by .bak or .tmp
*/
diff --git a/g10/mainproc.c b/g10/mainproc.c
index f4e5f45c3..3c1508d89 100644
--- a/g10/mainproc.c
+++ b/g10/mainproc.c
@@ -387,7 +387,7 @@ proc_pubkey_enc (ctrl_t ctrl, CTX c, PACKET *pkt)
to the Libgcrypt defined one. This is due a chicken-egg
problem: We need to have code in Libgcrypt for a new
algorithm so to implement a proposed new algorithm before the
- IANA will finally assign an OpenPGP indentifier. */
+ IANA will finally assign an OpenPGP identifier. */
snprintf (buf, sizeof buf, "%08lX%08lX %d 0",
(ulong)enc->keyid[0], (ulong)enc->keyid[1], enc->pubkey_algo);
write_status_text (STATUS_ENC_TO, buf);
@@ -1091,7 +1091,7 @@ list_node (CTX c, kbnode_t node)
{
log_debug ("FIXME: No way to print secret key packets here\n");
- /* fixme: We may use a fucntion to turn a secret key packet into
+ /* fixme: We may use a function to turn a secret key packet into
a public key one and use that here. */
}
else if (node->pkt->pkttype == PKT_SIGNATURE)
@@ -1442,7 +1442,7 @@ do_proc_packets (ctrl_t ctrl, CTX c, iobuf_t a)
* I used it. Adding the MDC check here is a hack.
* The right solution is to initiate another context for encrypted
* packet and not to reuse the current one ... It works right
- * when there is a compression packet inbetween which adds just
+ * when there is a compression packet between which adds just
* an extra layer.
* Hmmm: Rewrite this whole module here??
*/
diff --git a/g10/misc.c b/g10/misc.c
index 7f0b08a28..861ba8752 100644
--- a/g10/misc.c
+++ b/g10/misc.c
@@ -98,7 +98,7 @@ register_secured_file (const char *fname)
struct stat buf;
struct secured_file_item *sf;
- /* Note that we stop immediatley if something goes wrong here. */
+ /* Note that we stop immediately if something goes wrong here. */
if (stat (fname, &buf))
log_fatal (_("fstat of '%s' failed in %s: %s\n"), fname,
"register_secured_file", strerror (errno));
@@ -498,7 +498,7 @@ openpgp_cipher_blocklen (cipher_algo_t algo)
}
/****************
- * Wrapper around the libgcrypt function with additonal checks on
+ * Wrapper around the libgcrypt function with additional checks on
* the OpenPGP contraints for the algo ID.
*/
int
@@ -862,7 +862,7 @@ pct_expando(const char *string,struct expando_args *args)
case 'f': /* Fingerprint of key being signed */
case 'p': /* Fingerprint of the primary key making the signature. */
- case 'g': /* Fingerprint of thge key making the signature. */
+ case 'g': /* Fingerprint of the key making the signature. */
{
byte array[MAX_FINGERPRINT_LEN];
size_t len;
@@ -1074,7 +1074,7 @@ string_to_digest_algo (const char *string)
{
int val;
- /* FIXME: We should make use of our wrapper fucntion and not assume
+ /* FIXME: We should make use of our wrapper function and not assume
that there is a 1 to 1 mapping between OpenPGP and Libgcrypt. */
val = gcry_md_map_name (string);
if (!val && string && (string[0]=='H' || string[0]=='h'))
diff --git a/g10/options.h b/g10/options.h
index 68f5d391a..6fca714dd 100644
--- a/g10/options.h
+++ b/g10/options.h
@@ -116,7 +116,7 @@ struct
int skip_verify;
int skip_hidden_recipients;
- /* TM_CLASSIC must be zero to accomodate trustdbs generated before
+ /* TM_CLASSIC must be zero to accommodate trustdbs generated before
we started storing the trust model inside the trustdb. */
enum
{
diff --git a/g10/packet.h b/g10/packet.h
index 387a5b5cd..9eb16cfd8 100644
--- a/g10/packet.h
+++ b/g10/packet.h
@@ -481,7 +481,7 @@ int search_packet( iobuf_t inp, PACKET *pkt, off_t *retpos, int with_uid );
reached.
Returns -1 when end of file is reached or an error code, if an
- error occured. (Note: this function never returns 0, because it
+ error occurred. (Note: this function never returns 0, because it
effectively keeps going until it gets an EOF.) */
int copy_all_packets( iobuf_t inp, iobuf_t out );
@@ -578,7 +578,7 @@ const byte *parse_sig_subpkt2 ( PKT_signature *sig,
constraints.
Returns 0 if the size is acceptable. Returns -2 if the buffer is
- definately too short. To check for an error, check whether the
+ definitely too short. To check for an error, check whether the
return value is less than 0. */
int parse_one_sig_subpkt( const byte *buffer, size_t n, int type );
diff --git a/g10/parse-packet.c b/g10/parse-packet.c
index 4e236cb81..53b75a68c 100644
--- a/g10/parse-packet.c
+++ b/g10/parse-packet.c
@@ -3019,7 +3019,7 @@ parse_mdc (IOBUF inp, int pkttype, unsigned long pktlen,
/*
* This packet is internally generated by us (ibn armor.c) to transfer
* some information to the lower layer. To make sure that this packet
- * is really a GPG faked one and not one comming from outside, we
+ * is really a GPG faked one and not one coming from outside, we
* first check that there is a unique tag in it.
*
* The format of such a control packet is:
diff --git a/g10/pkclist.c b/g10/pkclist.c
index d810f91d8..480578254 100644
--- a/g10/pkclist.c
+++ b/g10/pkclist.c
@@ -113,7 +113,7 @@ do_show_revocation_reason( PKT_signature *sig )
void
show_revocation_reason( PKT_public_key *pk, int mode )
{
- /* Hmmm, this is not so easy becuase we have to duplicate the code
+ /* Hmmm, this is not so easy because we have to duplicate the code
* used in the trustbd to calculate the keyflags. We need to find
* a clean way to check revocation certificates on keys and
* signatures. And there should be no duplicate code. Because we
@@ -1076,7 +1076,7 @@ build_pk_list (ctrl_t ctrl,
}
/* Do group expand here too. The trick here is to continue
- the loop if any expansion occured. The code above will
+ the loop if any expansion occurred. The code above will
then list all expanded keys. */
if (expand_id(answer,&backlog,0))
continue;
diff --git a/g10/pkglue.c b/g10/pkglue.c
index a83462187..c8a5d24d1 100644
--- a/g10/pkglue.c
+++ b/g10/pkglue.c
@@ -31,7 +31,7 @@
#include "main.h"
#include "options.h"
-/* FIXME: Better chnage the fucntion name because mpi_ is used by
+/* FIXME: Better change the function name because mpi_ is used by
gcrypt macros. */
gcry_mpi_t
get_mpi_from_sexp (gcry_sexp_t sexp, const char *item, int mpifmt)
diff --git a/g10/plaintext.c b/g10/plaintext.c
index aeee2ac49..94ede07ef 100644
--- a/g10/plaintext.c
+++ b/g10/plaintext.c
@@ -165,7 +165,7 @@ get_output_file (const byte *embedded_name, int embedded_namelen,
;
else
{
- /* Note: riscos stuff is not expected to wrok anymore. If we
+ /* Note: riscos stuff is not expected to work anymore. If we
want to port it again to riscos we should do most of the suff
in estream. FIXME: Consider to remove all riscos special
cases. */
diff --git a/g10/server.c b/g10/server.c
index d02f20e3c..e5539d5ac 100644
--- a/g10/server.c
+++ b/g10/server.c
@@ -257,7 +257,7 @@ cmd_recipient (assuan_context_t ctx, char *line)
then not be done for this key. If the policy is not to sign at all
if not all signer keys are valid, the client has to take care of
this. All SIGNER commands are cumulative until a RESET but they
- are *not* reset by an SIGN command becuase it can be expected that
+ are *not* reset by an SIGN command because it can be expected that
set of signers are used for more than one sign operation.
Note that this command returns an INV_RECP status which is a bit
diff --git a/g10/sig-check.c b/g10/sig-check.c
index 2cfc5da50..75b06e858 100644
--- a/g10/sig-check.c
+++ b/g10/sig-check.c
@@ -176,7 +176,7 @@ check_signature2 (PKT_signature *sig, gcry_md_hd_t digest, u32 *r_expiredate,
* like this feature here.
*
* Note that before 2.0.10, we used RIPE-MD160 for the hash
- * and accidently didn't include the timestamp and algorithm
+ * and accidentally didn't include the timestamp and algorithm
* information in the hash. Given that this feature is not
* commonly used and that a replay attacks detection should
* not solely be based on this feature (because it does not
diff --git a/g10/sqlite.c b/g10/sqlite.c
index 04f15d90c..599a3ef5d 100644
--- a/g10/sqlite.c
+++ b/g10/sqlite.c
@@ -179,7 +179,7 @@ sqlite3_stepx (sqlite3 *db,
rc = sqlite3_step (stmt);
if (rc != SQLITE_ROW)
- /* No more data (SQLITE_DONE) or an error occured. */
+ /* No more data (SQLITE_DONE) or an error occurred. */
break;
if (! callback)
diff --git a/g10/tdbio.c b/g10/tdbio.c
index c7432a85e..63ccfae21 100644
--- a/g10/tdbio.c
+++ b/g10/tdbio.c
@@ -87,7 +87,7 @@ static int cache_entries;
static int cache_is_dirty;
-/* An object to pass infomation to cmp_krec_fpr. */
+/* An object to pass information to cmp_krec_fpr. */
struct cmp_krec_fpr_struct
{
int pubkey_algo;
@@ -95,7 +95,7 @@ struct cmp_krec_fpr_struct
int fprlen;
};
-/* An object used to pass infomation to cmp_[s]dir. */
+/* An object used to pass information to cmp_[s]dir. */
struct cmp_xdir_struct
{
int pubkey_algo;
@@ -446,7 +446,7 @@ tdbio_sync()
/*
* Simple transactions system:
* Everything between begin_transaction and end/cancel_transaction
- * is not immediatly written but at the time of end_transaction.
+ * is not immediately written but at the time of end_transaction.
*
* NOTE: The transaction code is disabled in the 1.2 branch, as it is
* not yet used.
diff --git a/g10/test-stubs.c b/g10/test-stubs.c
index 0e6616cb9..a1988f0f8 100644
--- a/g10/test-stubs.c
+++ b/g10/test-stubs.c
@@ -54,7 +54,7 @@ g10_exit( int rc )
/* Stub:
- * We have to override the trustcheck from pkclist.c becuase
+ * We have to override the trustcheck from pkclist.c because
* this utility assumes that all keys in the keyring are trustworthy
*/
int
diff --git a/g10/tofu.c b/g10/tofu.c
index b1b9f7174..5e38d211b 100644
--- a/g10/tofu.c
+++ b/g10/tofu.c
@@ -573,7 +573,7 @@ initdb (sqlite3 *db, enum db_type type)
latter binding, we warn the user about the conflict and ask
for a policy decision about the new binding. We also change
the old binding's policy to ask if it was auto. So that we
- know why this occured, we also set conflict to 0xbaddecaf.
+ know why this occurred, we also set conflict to 0xbaddecaf.
*/
if (type == DB_EMAIL || type == DB_COMBINED)
rc = sqlite3_exec_printf
diff --git a/g10/trust.c b/g10/trust.c
index 38d957e41..a89b0e5e8 100644
--- a/g10/trust.c
+++ b/g10/trust.c
@@ -294,7 +294,7 @@ check_or_update_trustdb (void)
/*
* Return the validity information for PK. If the namehash is not
- * NULL, the validity of the corresponsing user ID is returned,
+ * NULL, the validity of the corresponding user ID is returned,
* otherwise, a reasonable value for the entire key is returned.
*/
unsigned int
@@ -641,7 +641,7 @@ clean_sigs_from_uid (kbnode_t keyblock, kbnode_t uidnode,
compacted. To "compact" a user ID, we simply remove ALL signatures
except the self-sig that caused the user ID to be remove-worthy.
We don't actually remove the user ID packet itself since it might
- be ressurected in a later merge. Note that this function requires
+ be resurrected in a later merge. Note that this function requires
that the caller has already done a merge_keys_and_selfsig().
TODO: change the import code to allow importing a uid with only a
diff --git a/g10/trustdb.c b/g10/trustdb.c
index b58d5e1c7..943357c1d 100644
--- a/g10/trustdb.c
+++ b/g10/trustdb.c
@@ -1887,7 +1887,7 @@ validate_keys (int interactive)
u32 start_time, next_expire;
/* Make sure we have all sigs cached. TODO: This is going to
- require some architectual re-thinking, as it is agonizingly slow.
+ require some architectural re-thinking, as it is agonizingly slow.
Perhaps combine this with reset_trust_records(), or only check
the caches on keys that are actually involved in the web of
trust. */
diff --git a/g10/keydb.h b/g10/keydb.h
index e909c0fec..882af35cf 100644
--- a/g10/keydb.h
+++ b/g10/keydb.h
@@ -288,7 +288,7 @@ unsigned long keydb_get_skipped_counter (KEYDB_HANDLE hd);
so that the next search starts at the beginning of the database
(the start of the first resource).
- Returns 0 on success and an error code if an error occured.
+ Returns 0 on success and an error code if an error occurred.
(Currently, this function always returns 0 if HD is valid.) */
gpg_error_t keydb_search_reset (KEYDB_HANDLE hd);
@@ -305,7 +305,7 @@ gpg_error_t keydb_search_reset (KEYDB_HANDLE hd);
If no key matches the search description, returns
GPG_ERR_NOT_FOUND. If there was a match, returns 0. If an error
- occured, returns an error code.
+ occurred, returns an error code.
The returned key is considered to be selected and the raw data can,
for instance, be returned by calling keydb_get_keyblock(). */
@@ -437,7 +437,7 @@ void getkey_disable_caches(void);
occurs.
If the data was not read from the cache, then the self-signed data
- has definately been merged into the public key using
+ has definitely been merged into the public key using
merge_selfsigs. */
int get_pubkey( PKT_public_key *pk, u32 *keyid );
@@ -751,7 +751,7 @@ KEYDB_HANDLE get_ctx_handle(GETKEY_CTX ctx);
free_public_key (sk);
if (gpg_err_code (err) != GPG_ERR_EOF)
; // An error occured.
*/
gpg_error_t enum_secret_keys (ctrl_t ctrl, void **context, PKT_public_key *pk);
@@ -751,7 +751,7 @@ KEYDB_HANDLE get_ctx_handle(GETKEY_CTX ctx);
free_public_key (sk);
if (gpg_err_code (err) != GPG_ERR_EOF)
- ; // An error occured.
+ ; // An error occurred.
*/
gpg_error_t enum_secret_keys (ctrl_t ctrl, void **context, PKT_public_key *pk);